<?php
/**
 * Reduxbiz Theme Customizer.
 *
 * @package Reduxbiz
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function reduxbiz_customize_register( $wp_customize ) {
	
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

   // Theme important links started
   class Redux_Theme_Info extends WP_Customize_Control {

      public $type = "redux-theme-info";

      public function render_content() {
         //Add Theme instruction, Support Forum, Demo Link, Rating Link
         $theme_info_links = array(
            'view-pro' => array(
               'link' => esc_url('http://reduxthemes.com/'),
               'text' => esc_html__('&mdash; by ReduxThemes.com', 'reduxbiz'),
            ),
            'theme-info' => array(
               'link' => esc_url(get_site_url().'/wp-admin/themes.php?page=redux-theme-info'),
               'text' => esc_html__('&mdash; Info & Share Your Love (Donate $)', 'reduxbiz'),
            ),
            'theme-webpage' => array(
               'link' => esc_url('http://reduxthemes.com/themes/reduxbiz/'),
               'text' => esc_html__('&mdash; Theme Page @ ReduxThemes.com', 'reduxbiz'),
            ),
            'theme-support' => array(
               'link' => esc_url('mailto:info@reduxthemes.com'),
               'text' => esc_html__('&mdash; Support Email: info@reduxthemes.com', 'reduxbiz'),
            ),

         );
         
		echo '<p><img src="'. REDUX_CHILD_URL.'/screenshot.jpg" width="100%" height="auto"/></p>';

         foreach ($theme_info_links as $theme_info_link) {
            echo '<p><a target="_blank" href="' . $theme_info_link['link'] . '" >' . esc_attr($theme_info_link['text']) . ' </a></p>';
         }

      }

   }
   
   $wp_customize->add_section('redux_theme_info', array(
      'priority' => 1,
      'title' => __('Theme Info & Support', 'reduxbiz'),
   ));

   $wp_customize->add_setting('theme_info', array(
	'capability' => 'edit_theme_options',
	'sanitize_callback' => 'redux_no_sanitize',      
   ));

   $wp_customize->add_control(new Redux_Theme_Info($wp_customize, 'theme_info', array(
      'section' => 'redux_theme_info',
   )));
      
   // Theme Important Links Ended
     
   // Start of the Design Options
   $wp_customize->add_panel('redux_general_options', array(
      'capabitity' => 'edit_theme_options',
      'priority' => 505,
      'title' => __('Theme Design', 'reduxbiz')
   ));

   // site layout setting
   $wp_customize->add_section('redux_theme_options', array(
      'priority' => 1,
      'title' => __('Site Layout', 'reduxbiz'),
      'panel' => 'redux_general_options'
   ));

   	$wp_customize->add_setting( REDUX_THEME_NAME.'[sticky_header]', array(
		'default'           => '',
		'sanitize_callback' => 'redux_sanitize_checkbox',
	) );

	$wp_customize->add_control( REDUX_THEME_NAME.'[sticky_header]', array(
		'label'             => esc_html__( 'Fixed header when scrolling down.', 'reduxbiz' ),
		'section'           => 'redux_theme_options',
		'type'              => 'checkbox',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[blog_fullpost]', array(
		'default'           => 'no',
		'sanitize_callback' => 'redux_sanitize_yesno',
	) );
	
	$wp_customize->add_control( REDUX_THEME_NAME.'[blog_fullpost]', array(
		'label'             => esc_html__( 'Show full articles on blog index page?', 'reduxbiz' ),
		'section'           => 'redux_theme_options',
		'type'              => 'radio',
		'choices'           => array(
			'no' => esc_html__( 'No - Summary/Excerpt Only', 'reduxbiz' ),
			'yes' => esc_html__( 'Yes - Show Full Content', 'reduxbiz' ),
		),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[footer_top_column]', array(
		'default'           => 'column-1',
		'sanitize_callback' => 'redux_sanitize_column',
	) );

	$wp_customize->add_control( REDUX_THEME_NAME.'[footer_top_column]', array(
		'label'             => esc_html__( 'Top Footer Area Layout', 'reduxbiz' ),
		'section'           => 'redux_theme_options',
		'type'              => 'radio',
		'choices'           => array(
			'column-1' => esc_html__( '1 Column', 'reduxbiz' ),
			'column-2' => esc_html__( '2 Columns', 'reduxbiz' ),
			'column-3' => esc_html__( '3 Columns', 'reduxbiz' ),
		),
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[footer_bottom_column]', array(
		'default'           => 'column-3',
		'sanitize_callback' => 'redux_sanitize_column',
	) );

	$wp_customize->add_control( REDUX_THEME_NAME.'[footer_bottom_column]', array(
		'label'             => esc_html__( 'Bottom Footer Area Layout', 'reduxbiz' ),
		'section'           => 'redux_theme_options',
		'type'              => 'radio',
		'choices'           => array(
			'column-1' => esc_html__( '1 Column', 'reduxbiz' ),
			'column-2' => esc_html__( '2 Columns', 'reduxbiz' ),
			'column-3' => esc_html__( '3 Columns', 'reduxbiz' ),
		),
	) );

   // Site Primary Color
   $wp_customize->add_section('redux_colors', array(
      'panel' => 'redux_general_options',
      'priority' => 6,
      'title' => __('Website Colors', 'reduxbiz')
   ));

   $wp_customize->add_setting(REDUX_THEME_NAME.'[primary_color]', array(
      'default' => '#19bce9',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'redux_color_option_hex_sanitize',
      'sanitize_js_callback' => 'redux_color_escaping_option_sanitize'
   ));

   $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, REDUX_THEME_NAME.'[primary_color]', array(
      'label' => __('Website Primary Color', 'reduxbiz'),
      'section' => 'redux_colors',
   )));
      
   $wp_customize->add_section('redux_custom_css', array(
      'priority' => 8,
      'title' => __('Custom Codes & CSS', 'reduxbiz'),
      'panel' => 'redux_general_options'
   ));

   $wp_customize->add_setting(REDUX_THEME_NAME.'[custom_css]', array(
      'default' => '',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
      'sanitize_js_callback' => 'esc_attr'
   ));

   $wp_customize->add_control(REDUX_THEME_NAME.'[custom_css]', array(
      'label' => __('Add Custom CSS', 'reduxbiz'),
      'section' => 'redux_custom_css',
      'type' => 'textarea',
   ));

   // End of Design Options


   // Start of the Home Page Options
   $wp_customize->add_panel('redux_homepage_options', array(
      'capabitity' => 'edit_theme_options',
      'priority' => 505,
      'title' => __('Home Page', 'reduxbiz')
   ));
   	
	$wp_customize->add_section( 'redux_homepage_heropanel', array(
		'title'             => esc_html__( 'Hero - Banner', 'reduxbiz' ),
		'priority'          => 140,
		'panel'=> 'redux_homepage_options',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[hero_image]', array(
		'default'           => '',
		'sanitize_callback' => 'redux_no_sanitize',
	) );

	$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, REDUX_THEME_NAME.'[hero_image]', array(
	  'label' => __( 'Hero Image', 'reduxbiz'),
	  'section' => 'redux_homepage_heropanel',
	  'mime_type' => 'image',
	) ) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[hero_title]', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( REDUX_THEME_NAME.'[hero_title]', array(
		'label' => __( 'Hero Title','reduxbiz'),
		'section' => 'redux_homepage_heropanel',
		'type' => 'text',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[hero_text]', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( REDUX_THEME_NAME.'[hero_text]', array(
		'label' => __( 'Hero Text (Text/HTML)', 'reduxbiz'),
		'section' => 'redux_homepage_heropanel',
		'type' => 'textarea',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[hero_buttontext]', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr',
	) );
	
	$wp_customize->add_control( REDUX_THEME_NAME.'[hero_buttontext]', array(
		'label' => __( 'Hero Button Text','reduxbiz' ),
		'section' => 'redux_homepage_heropanel',
		'type' => 'text',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[hero_buttonlink]', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[hero_buttonlink]', array(
		'label' => __( 'Hero Button Link', 'reduxbiz' ),
		'section' => 'redux_homepage_heropanel',
		'type' => 'text',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[hero_style]', array(
		'default'           => 'dark',
		'sanitize_callback' => 'redux_sanitize_darklight',
	) );
	
	$wp_customize->add_control( REDUX_THEME_NAME.'[hero_style]', array(
		'label' => __( 'Hero Text Style', 'reduxbiz' ),
		'section' => 'redux_homepage_heropanel',
		'type' => 'radio',
		'choices' => array ('dark'=>__('Light Background + Dark Text', 'reduxbiz'), 'light'=>__('Dark Background + Light Text', 'reduxbiz')),
	) );

	$wp_customize->add_section( 'redux_homepage_actionbar', array(
		'title'             => esc_html__( 'Tagline / Call to Action', 'reduxbiz' ),
		'priority'          => 140,
		'panel'=> 'redux_homepage_options',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[actionbar_show]', array(
		'default'           => 'off',
		'sanitize_callback' => 'redux_sanitize_onoff',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[actionbar_show]', array(
		'label' => __( 'Tagline Section (Show/Hide)', 'reduxbiz' ),
		'section' => 'redux_homepage_actionbar',
		'type' => 'radio',
		'choices' => array ('on'=>__('Enable', 'reduxbiz'), 'off'=>__('Disable', 'reduxbiz')),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[actionbar_heading]', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[actionbar_heading]', array(
		'label' => __( 'Heading', 'reduxbiz' ),
		'section' => 'redux_homepage_actionbar',
		'type' => 'text',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[actionbar_text]', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[actionbar_text]', array(
		'label' => __( 'Tagline/Call to Action (Text)', 'reduxbiz' ),
		'section' => 'redux_homepage_actionbar',
		'type' => 'textarea',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[actionbar_buttontext]', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr',
	) );
	
	$wp_customize->add_control( REDUX_THEME_NAME.'[actionbar_buttontext]', array(
		'label' => __( 'Action Button Text', 'reduxbiz' ),
		'section' => 'redux_homepage_actionbar',
		'type' => 'text',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[actionbar_buttonlink]', array(
		'default'           => '',
	      'sanitize_callback' => 'esc_url',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[actionbar_buttonlink]', array(
		'label' => __( 'Action Button Link', 'reduxbiz' ),
		'section' => 'redux_homepage_actionbar',
		'type' => 'text',
	) );	
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[actionbar_style]', array(
		'default'           => 'dark',
		'sanitize_callback' => 'redux_sanitize_darklight',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[actionbar_style]', array(
		'label' => __( 'Call to Action Style', 'reduxbiz' ),
		'section' => 'redux_homepage_actionbar',
		'type' => 'radio',
		'choices' => array ('dark'=>__('Light Background + Dark Text', 'reduxbiz'), 'light'=>__('Dark Background + Light Text', 'reduxbiz')),
	) );

	$wp_customize->add_section( 'redux_homepage_services', array(
		'title'             => esc_html__( 'Services (Settings)', 'reduxbiz' ),
		'priority'          => 350,
		'panel'=> 'redux_homepage_options',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[services_show]', array(
		'default'           => 'off',
		'sanitize_callback' => 'redux_sanitize_onoff',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[services_show]', array(
		'label' => __( 'Services Section (Show/Hide)', 'reduxbiz' ),
		'section' => 'redux_homepage_services',
		'type' => 'radio',
		'choices' => array ('on'=>'Enable', 'off'=>'Disable'),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[services_heading]', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[services_heading]', array(
		'label' => __( 'Services Heading', 'reduxbiz' ),
		'section' => 'redux_homepage_services',
		'type' => 'text',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[services_text]', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[services_text]', array(
		'label' => __( 'Services Intro Text', 'reduxbiz' ),
		'section' => 'redux_homepage_services',
		'type' => 'textarea',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[services_style]', array(
		'default'           => 'dark',
		'sanitize_callback' => 'redux_sanitize_darklight',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[services_style]', array(
		'label' => __( 'Services Style', 'reduxbiz' ),
		'section' => 'redux_homepage_services',
		'type' => 'radio',
		'choices' => array ('dark'=>__('Light Background + Dark Text', 'reduxbiz'), 'light'=>__('Dark Background + Light Text', 'reduxbiz')),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[services_image]', array(
		'default'           => '',
		'sanitize_callback' => 'redux_no_sanitize',
	) );

	$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, REDUX_THEME_NAME.'[services_image]', array(
		'label' => __( 'Services Background Image', 'reduxbiz'),
		'section' => 'redux_homepage_services',
	  	'mime_type' => 'image',
	) ) );
	
	//Define the Number of Services Required
	$services_number = 4;
	
	if ( ($services_number != '') && ($services_number != '0') ) {
		$i = 1;
		while ($i <= $services_number){

			$wp_customize->add_section( 'redux_homepage_services'.$i, array(
				'title'             => esc_html__( 'Service # ', 'reduxbiz' ).$i,
				'priority'          =>400,
				'panel' => 'redux_homepage_options',
			) );

			$wp_customize->add_setting( REDUX_THEME_NAME.'[services_image'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'redux_no_sanitize',
			) );
				
			$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, REDUX_THEME_NAME.'[services_image'.$i.']', array(
			  'label' => __( 'Service Image', 'reduxbiz'),
			  'section' => 'redux_homepage_services'.$i,
			  'mime_type' => 'image',
			) ) );
			
			$wp_customize->add_setting( REDUX_THEME_NAME.'[services_name'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'esc_attr',
			) );
				
			$wp_customize->add_control( REDUX_THEME_NAME.'[services_name'.$i.']', array(
				'label' => __( 'Service Title', 'reduxbiz' ),
				'section' => 'redux_homepage_services'.$i,
				'type' => 'text',
			) );
		
			$wp_customize->add_setting( REDUX_THEME_NAME.'[services_text'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'wp_kses_post',
			) );
		
			$wp_customize->add_control( REDUX_THEME_NAME.'[services_text'.$i.']', array(
				'label' => __( 'Text (Text/HTML)', 'reduxbiz' ),
				'section' => 'redux_homepage_services'.$i,
				'type' => 'textarea',
			) );
		
			$wp_customize->add_setting( REDUX_THEME_NAME.'[services_link'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'esc_url',
			) );
						
			$wp_customize->add_control( REDUX_THEME_NAME.'[services_link'.$i.']', array(
				'label' => __( 'Web Link', 'reduxbiz' ),
				'section' => 'redux_homepage_services'.$i,
				'type' => 'text',
			) );

			$wp_customize->add_setting( REDUX_THEME_NAME.'[services_linktext'.$i.']', array(
				'default'           => __( 'details', 'reduxbiz' ),
				'sanitize_callback' => 'esc_attr',
			) );
			
			$wp_customize->add_control( REDUX_THEME_NAME.'[services_linktext'.$i.']', array(
				'label' => __( 'Web Link Text', 'reduxbiz' ),
				'section' => 'redux_homepage_services'.$i,
				'type' => 'text',
			) );
									
			$i++;
		
		}
	
	}
					
	$wp_customize->add_section( 'redux_homepage_testimonials', array(
		'title'             => esc_html__( 'Testimonials (Settings)', 'reduxbiz' ),
		'priority'          => 450,
		'panel'=> 'redux_homepage_options',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[testimonial_show]', array(
		'default'           => 'off',
		'sanitize_callback' => 'redux_sanitize_onoff',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[testimonial_show]', array(
		'label' => __( 'Testimonial Section (Show/Hide)', 'reduxbiz' ),
		'section' => 'redux_homepage_testimonials',
		'type' => 'radio',
		'choices' => array ('on'=>'Enable', 'off'=>'Disable'),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[testimonial_heading]', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[testimonial_heading]', array(
		'label' => __( 'Testimonial Heading', 'reduxbiz' ),
		'section' => 'redux_homepage_testimonials',
		'type' => 'text',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[testimonial_text]', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[testimonial_text]', array(
		'label' => __( 'Testimonial Intro (Text/HTML)', 'reduxbiz' ),
		'section' => 'redux_homepage_testimonials',
		'type' => 'textarea',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[testimonial_style]', array(
		'default'           => 'dark',
		'sanitize_callback' => 'redux_sanitize_darklight',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[testimonial_style]', array(
		'label' => __( 'Testimonial Text Style', 'reduxbiz' ),
		'section' => 'redux_homepage_testimonials',
		'type' => 'radio',
		'choices' => array ('dark'=>__('Light Background + Dark Text', 'reduxbiz'), 'light'=>__('Dark Background + Light Text', 'reduxbiz')),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[testimonial_image]', array(
		'default'           => '',
		'sanitize_callback' => 'redux_no_sanitize',
	) );

	$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, REDUX_THEME_NAME.'[testimonial_image]', array(
		'label' => __( 'Testimonial Background Image', 'reduxbiz'),
		'section' => 'redux_homepage_testimonials',
	  	'mime_type' => 'image',
	) ) );
	
	//Define the Number of Testimonials Required
	$testimonial_number = 4;
	
	if ( ($testimonial_number != '') && ($testimonial_number != '0') ) {
		$i = 1;
		while ($i <= $testimonial_number){

			$wp_customize->add_section( 'redux_homepage_testimonials'.$i, array(
				'title'             => esc_html__( 'Testimonial # ', 'reduxbiz' ).$i,
				'priority'          =>500,
				'panel' => 'redux_homepage_options',
			) );

			$wp_customize->add_setting( REDUX_THEME_NAME.'[testimonial_image'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'redux_no_sanitize',
			) );
				
			$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, REDUX_THEME_NAME.'[testimonial_image'.$i.']', array(
			  'label' => __( 'Person Image', 'reduxbiz'),
			  'section' => 'redux_homepage_testimonials'.$i,
			  'mime_type' => 'image',
			) ) );
			
			$wp_customize->add_setting( REDUX_THEME_NAME.'[testimonial_name'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'esc_attr',
			) );
				
			$wp_customize->add_control( REDUX_THEME_NAME.'[testimonial_name'.$i.']', array(
				'label' => __( 'Person Name', 'reduxbiz' ),
				'section' => 'redux_homepage_testimonials'.$i,
				'type' => 'text',
			) );
		
			$wp_customize->add_setting( REDUX_THEME_NAME.'[testimonial_link'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'esc_url',
			) );
				
			$wp_customize->add_control( REDUX_THEME_NAME.'[testimonial_link'.$i.']', array(
				'label' => __( 'Web Link (Optional)', 'reduxbiz' ),
				'section' => 'redux_homepage_testimonials'.$i,
				'type' => 'text',
			) );
		
			$wp_customize->add_setting( REDUX_THEME_NAME.'[testimonial_text'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'wp_kses_post',
			) );
		
			$wp_customize->add_control( REDUX_THEME_NAME.'[testimonial_text'.$i.']', array(
				'label' => __( 'Text (Text/HTML)', 'reduxbiz' ),
				'section' => 'redux_homepage_testimonials'.$i,
				'type' => 'textarea',
			) );
			
			$i++;
		
		}
	
	}
			
   
   	$wp_customize->add_section( 'redux_homepage_team', array(
		'title'             => esc_html__( 'Team Members (Settings)', 'reduxbiz' ),
		'priority'          => 650,
		'panel'=> 'redux_homepage_options',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[team_show]', array(
		'default'           => 'off',
		'sanitize_callback' => 'redux_sanitize_onoff',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[team_show]', array(
		'label' => __( 'Team Section (Show/Hide)', 'reduxbiz' ),
		'section' => 'redux_homepage_team',
		'type' => 'radio',
		'choices' => array ('on'=>'Enable', 'off'=>'Disable'),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[team_heading]', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[team_heading]', array(
		'label' => __( 'Team Heading', 'reduxbiz' ),
		'section' => 'redux_homepage_team',
		'type' => 'text',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[team_text]', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[team_text]', array(
		'label' => __( 'Team Intro (Text/HTML)', 'reduxbiz' ),
		'section' => 'redux_homepage_team',
		'type' => 'textarea',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[team_style]', array(
		'default'           => 'dark',
		'sanitize_callback' => 'redux_sanitize_darklight',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[team_style]', array(
		'label' => __( 'Team Style', 'reduxbiz' ),
		'section' => 'redux_homepage_team',
		'type' => 'radio',
		'choices' => array ('dark'=>__('Light Background + Dark Text', 'reduxbiz'), 'light'=>__('Dark Background + Light Text', 'reduxbiz')),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[team_image]', array(
		'default'           => '',
		'sanitize_callback' => 'redux_no_sanitize',
	) );

	$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, REDUX_THEME_NAME.'[team_image]', array(
		'label' => __( 'Team Background Image', 'reduxbiz'),
		'section' => 'redux_homepage_team',
	  	'mime_type' => 'image',
	) ) );
	
	//Define the Number of Services Required
	$teammember_number = 4;
	
	if ( ($teammember_number != '') && ($teammember_number != '0') ) {
		$i = 1;
		while ($i <= $teammember_number){

			$wp_customize->add_section( 'redux_homepage_teammember'.$i, array(
				'title'             => esc_html__( 'Team Member # ', 'reduxbiz' ).$i,
				'priority'          =>700,
				'panel' => 'redux_homepage_options',
			) );

			$wp_customize->add_setting( REDUX_THEME_NAME.'[teammember_image'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'redux_no_sanitize',
			) );
				
			$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, REDUX_THEME_NAME.'[teammember_image'.$i.']', array(
			  'label' => __( 'Team Member Image', 'reduxbiz'),
			  'section' => 'redux_homepage_teammember'.$i,
			  'mime_type' => 'image',
			) ) );
			
			$wp_customize->add_setting( REDUX_THEME_NAME.'[teammember_name'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'esc_attr',
			) );
				
			$wp_customize->add_control( REDUX_THEME_NAME.'[teammember_name'.$i.']', array(
				'label' => __( 'Team Member Name', 'reduxbiz' ),
				'section' => 'redux_homepage_teammember'.$i,
				'type' => 'text',
			) );

			$wp_customize->add_setting( REDUX_THEME_NAME.'[teammember_designation'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'esc_attr',
			) );
			
			$wp_customize->add_control( REDUX_THEME_NAME.'[teammember_designation'.$i.']', array(
				'label' => __( 'Designation', 'reduxbiz' ),
				'section' => 'redux_homepage_teammember'.$i,
				'type' => 'text',
			) );
					
			$wp_customize->add_setting( REDUX_THEME_NAME.'[teammember_text'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'wp_kses_post',
			) );
		
			$wp_customize->add_control( REDUX_THEME_NAME.'[teammember_text'.$i.']', array(
				'label' => __( 'Team Member Intro (Text/HTML)', 'reduxbiz' ),
				'section' => 'redux_homepage_teammember'.$i,
				'type' => 'textarea',
			) );

			$wp_customize->add_setting( REDUX_THEME_NAME.'[teammember_facebook'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'esc_url',
			) );
						
			$wp_customize->add_control( REDUX_THEME_NAME.'[teammember_facebook'.$i.']', array(
				'label' => __( 'Facebook Link (Optional)', 'reduxbiz' ),
				'section' => 'redux_homepage_teammember'.$i,
				'type' => 'text',
			) );

			$wp_customize->add_setting( REDUX_THEME_NAME.'[teammember_twitter'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'esc_url',
			) );
						
			$wp_customize->add_control( REDUX_THEME_NAME.'[teammember_twitter'.$i.']', array(
				'label' => __( 'Twitter Link (Optional)', 'reduxbiz' ),
				'section' => 'redux_homepage_teammember'.$i,
				'type' => 'text',
			) );
											
			$wp_customize->add_setting( REDUX_THEME_NAME.'[teammember_linkedin'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'esc_url',
			) );
						
			$wp_customize->add_control( REDUX_THEME_NAME.'[teammember_linkedin'.$i.']', array(
				'label' => __( 'Linkedin Link (Optional)', 'reduxbiz' ),
				'section' => 'redux_homepage_teammember'.$i,
				'type' => 'text',
			) );

			$wp_customize->add_setting( REDUX_THEME_NAME.'[teammember_link'.$i.']', array(
				'default'           => '',
				'sanitize_callback' => 'esc_url',
			) );
						
			$wp_customize->add_control( REDUX_THEME_NAME.'[teammember_link'.$i.']', array(
				'label' => __( 'Web Link (Optional)', 'reduxbiz' ),
				'section' => 'redux_homepage_teammember'.$i,
				'type' => 'text',
			) );
			
									
			$i++;
		
		}
	
	}
	
	$wp_customize->add_section( 'redux_homepage_contactform', array(
		'title'             => esc_html__( 'Contact Form', 'reduxbiz' ),
		'priority'          => 1000,
		'panel'=> 'redux_homepage_options',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactform_show]', array(
		'default'           => 'off',
		'sanitize_callback' => 'redux_sanitize_onoff',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactform_show]', array(
		'label' => __( 'Contact Form (Show/Hide)', 'reduxbiz' ),
		'section' => 'redux_homepage_contactform',
		'type' => 'radio',
		'choices' => array ('on'=>'Enable', 'off'=>'Disable'),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactform_heading]', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactform_heading]', array(
		'label' => __( 'Heading', 'reduxbiz' ),
		'section' => 'redux_homepage_contactform',
		'type' => 'text',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactform_form]', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactform_form]', array(
		'label' => __( 'Contact Text/Form Code (Text/HTML or ShortCode)', 'reduxbiz' ),
		'section' => 'redux_homepage_contactform',
		'type' => 'textarea',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactform_style]', array(
		'default'           => 'dark',
		'sanitize_callback' => 'redux_sanitize_darklight',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactform_style]', array(
		'label' => __( 'Contact Section Style', 'reduxbiz' ),
		'section' => 'redux_homepage_contactform',
		'type' => 'radio',
		'choices' => array ('dark'=>__('Light Background + Dark Text', 'reduxbiz'), 'light'=>__('Dark Background + Light Text', 'reduxbiz')),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactform_image]', array(
		'default'           => '',
		'sanitize_callback' => 'redux_no_sanitize',
	) );

	$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, REDUX_THEME_NAME.'[contactform_image]', array(
		'label' => __( 'Contact Background Image', 'reduxbiz'),
		'section' => 'redux_homepage_contactform',
	  	'mime_type' => 'image',
	) ) );

	$wp_customize->add_section( 'redux_homepage_contactinfo', array(
		'title'             => esc_html__( 'Contact Info', 'reduxbiz' ),
		'priority'          => 900,
		'panel'=> 'redux_homepage_options',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactinfo_show]', array(
		'default'           => 'off',
		'sanitize_callback' => 'redux_sanitize_onoff',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactinfo_show]', array(
		'label' => __( 'Contact Form (Show/Hide)', 'reduxbiz' ),
		'section' => 'redux_homepage_contactinfo',
		'type' => 'radio',
		'choices' => array ('on'=>'Enable', 'off'=>'Disable'),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactinfo_heading]', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactinfo_heading]', array(
		'label' => __( 'Heading', 'reduxbiz' ),
		'section' => 'redux_homepage_contactinfo',
		'type' => 'text',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactinfo_text]', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactinfo_text]', array(
		'label' => __( 'Contact Address (Text/HTML)', 'reduxbiz' ),
		'section' => 'redux_homepage_contactinfo',
		'type' => 'textarea',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactinfo_phone]', array(
		'default'           => '',
		'sanitize_callback' => 'esc_attr',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactinfo_phone]', array(
		'label' => __( 'Phone', 'reduxbiz' ),
		'section' => 'redux_homepage_contactinfo',
		'type' => 'text',
	) );

	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactinfo_email]', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_email',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactinfo_email]', array(
		'label' => __( 'Email', 'reduxbiz' ),
		'section' => 'redux_homepage_contactinfo',
		'type' => 'text',
	) );
			
	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactinfo_map]', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactinfo_map]', array(
		'label' => __( 'Location Map (HTML/ShortCode)', 'reduxbiz' ),
		'section' => 'redux_homepage_contactinfo',
		'type' => 'textarea',
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactinfo_style]', array(
		'default'           => 'dark',
		'sanitize_callback' => 'redux_sanitize_darklight',
	) );
		
	$wp_customize->add_control( REDUX_THEME_NAME.'[contactinfo_style]', array(
		'label' => __( 'Contact Info Section Style', 'reduxbiz' ),
		'section' => 'redux_homepage_contactinfo',
		'type' => 'radio',
		'choices' => array ('dark'=>__('Light Background + Dark Text', 'reduxbiz'), 'light'=>__('Dark Background + Light Text', 'reduxbiz')),
	) );
	
	$wp_customize->add_setting( REDUX_THEME_NAME.'[contactinfo_image]', array(
		'default'           => '',
		'sanitize_callback' => 'redux_no_sanitize',
	) );

	$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, REDUX_THEME_NAME.'[contactinfo_image]', array(
		'label' => __( 'Contact Info Background Image', 'reduxbiz' ),
		'section' => 'redux_homepage_contactinfo',
	  	'mime_type' => 'image',
	) ) );

   	$wp_customize->add_section( 'redux_homepage_layout', array(
		'title'             => esc_html__( 'Home Page Layout', 'reduxbiz' ),
		'priority'          => 1950,
		'panel'=> 'redux_homepage_options',
	) );
		
	$wp_customize->add_setting( REDUX_THEME_NAME.'[homepage_pagecontent]', array(
		'default'           => 'no',
		'sanitize_callback' => 'redux_sanitize_yesno',
	) );

	$wp_customize->add_control( REDUX_THEME_NAME.'[homepage_pagecontent]', array(
		'label'             => esc_html__( 'Show Page Content on Home Page', 'reduxbiz' ),
		'section'           => 'redux_homepage_layout',
		'type'              => 'radio',
		'choices'           => array(
			'yes' => esc_html__( 'Yes (Show Page Content)', 'reduxbiz' ),
			'no' => esc_html__( 'No (Hide Any Page Content)', 'reduxbiz' ),
		),
	) );
				
}
add_action( 'customize_register', 'reduxbiz_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function reduxbiz_customize_preview_js() {
	wp_enqueue_script( 'reduxbiz_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'reduxbiz_customize_preview_js' );

/**
 * Sanitize the checkbox.
 *
 * @param boolean $input.
 * @return boolean true if portfolio page template displays title and content.
 */
function redux_sanitize_checkbox( $input ) {
	if ( 1 == $input ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Sanitize the Column value.
 *
 * @param string $column.
 * @return string (column-1|column-2|column-3).
 */
function redux_sanitize_column( $column ) {
	if ( ! in_array( $column, array( 'column-1', 'column-2', 'column-3' ) ) ) {
		$column = 'column-1';
	}
	return $column;
}

// Radio/select sanitization
function redux_radio_select_sanitize( $input, $setting ) {
	// Ensuring that the input is a slug.
	$input = sanitize_key( $input );
	// Get the list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;
	// If the input is a valid key, return it, else, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

// checkbox sanitize
function redux_checkbox_sanitize($input) {
      if ( $input == 1 ) {
         return 1;
      } else {
         return '';
      }
}

// yes/no radio sanitize
function redux_sanitize_yesno($input) {
	if ( $input == 'yes' ) {
		return 'yes';
	} else {
		return 'no';
      }
}
   
// On/Off radio sanitize
function redux_sanitize_onoff($input) {
	if ( $input == 'on' ) {
		return 'on';
	} else {
		return 'off';
	}
}
   
// Dark/Light radio sanitize
function redux_sanitize_darklight($input) {
	if ( $input == 'dark' ) {
		return 'dark';
	} else {
		return 'light';
	}
}
   
// text-area sanitize
function redux_text_sanitize($input) {
	return wp_kses_post( force_balance_tags( $input ) );
}

// color sanitization
function redux_color_option_hex_sanitize($color) {
	if ($unhashed = sanitize_hex_color_no_hash($color))
		return '#' . $unhashed;
	return $color;
}

function redux_color_escaping_option_sanitize($input) {
	$input = esc_attr($input);
	return $input;
}

// nothing to sanitize
function redux_no_sanitize($input) {
	return $input;
}